@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Juno;
 {
-  $Juno::VERSION = '0.004';
+  $Juno::VERSION = '0.005';
 }
 # ABSTRACT: Asynchronous event-driven checking mechanism
 
@@ -24,11 +24,17 @@ has interval => (
     default => 10,
 );
 
+has after => (
+    is      => 'ro',
+    isa     => 'Num',
+    default => 0,
+);
+
 has prop_attributes => (
     is      => 'ro',
     isa     => 'ArrayRef[Str]',
     default => sub { [
-        qw/hosts interval/
+        qw/hosts interval after/
     ] },
 );
 
@@ -90,7 +96,7 @@ Juno - Asynchronous event-driven checking mechanism
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -137,6 +143,12 @@ The interval for every check.
 
 Default: 10 seconds.
 
+=head2 after
+
+delay seconds for first check.
+
+Default: 0 second
+
 =head2 checks
 
 The checks you want to run.
